@@ -44,6 +44,7 @@ typedef enum {
 	GKR_ASK_REQUEST_OK_BUTTON               = 0x0100,
 	GKR_ASK_REQUEST_CANCEL_BUTTON           = 0x0200,
 	GKR_ASK_REQUEST_CREATE_BUTTON           = 0x0400,
+	GKR_ASK_REQUEST_CHANGE_BUTTON           = 0x0800,
 	GKR_ASK_REQUEST_ALLOW_BUTTON            = 0x1000,
 	GKR_ASK_REQUEST_ALLOW_FOREVER_BUTTON    = 0x2000,
 	GKR_ASK_REQUEST_DENY_BUTTON             = 0x4000,
@@ -64,8 +65,12 @@ typedef enum {
 	(GKR_ASK_REQUEST_OK_BUTTON | GKR_ASK_REQUEST_CANCEL_BUTTON)
 #define GKR_ASK_REQUEST_CREATE_CANCEL_BUTTONS \
 	(GKR_ASK_REQUEST_CREATE_BUTTON | GKR_ASK_REQUEST_CANCEL_BUTTON)
+#define GKR_ASK_REQUEST_CHANGE_CANCEL_BUTTONS \
+    (GKR_ASK_REQUEST_CHANGE_BUTTON | GKR_ASK_REQUEST_CANCEL_BUTTON)
 #define GKR_ASK_REQUEST_NEW_PASSWORD  \
-	(GKR_ASK_REQUEST_PASSWORD | GKR_ASK_REQUEST_CONFIRM_PASSWORD | GKR_ASK_REQUEST_CREATE_CANCEL_BUTTONS) 
+	(GKR_ASK_REQUEST_PASSWORD | GKR_ASK_REQUEST_CONFIRM_PASSWORD | GKR_ASK_REQUEST_CREATE_CANCEL_BUTTONS)
+#define GKR_ASK_REQUEST_CHANGE_PASSWORD \
+    ( GKR_ASK_REQUEST_PASSWORD | GKR_ASK_REQUEST_CONFIRM_PASSWORD | GKR_ASK_REQUEST_CHANGE_CANCEL_BUTTONS)
 #define GKR_ASK_REQUEST_PROMPT_PASSWORD \
 	(GKR_ASK_REQUEST_PASSWORD | GKR_ASK_REQUEST_OK_DENY_BUTTONS)
 #define GKR_ASK_REQUEST_ACCESS_SOMETHING \
